import { KatexOptions } from 'katex';
import { MarkedOptions } from 'marked';
import { HTMLElement } from 'nodom';
import { NbRenderer, NbRendererOpts as BaseOptions } from 'ipynb2html-core';
export { default as version } from './version';
export { NbRenderer };
export declare type NbRendererOpts = BaseOptions<HTMLElement> & {
    /**
     * The prefix to be used for all CSS class names except `lang-*`.
     * Default is `nb-`.
     */
    classPrefix?: string;
    /**
     * Options for the KaTeX math renderer. Default is
     * `{ displayMode: true, throwOnError: false }`. The provided options will
     * be merged with the default.
     */
    katexOpts?: KatexOptions;
    /**
     * Options for the marked Markdown renderer.
     */
    markedOpts?: MarkedOptions;
};
declare const _default: (opts?: NbRendererOpts) => {
    Notebook: (notebook: import("ipynb2html-core").Notebook) => HTMLElement;
    Cell: (cell: import("ipynb2html-core").Cell, notebook: import("ipynb2html-core").Notebook) => HTMLElement;
    MarkdownCell: (cell: import("ipynb2html-core").MarkdownCell, _notebook: import("ipynb2html-core").Notebook) => HTMLElement;
    RawCell: (cell: import("ipynb2html-core").RawCell, _notebook: import("ipynb2html-core").Notebook) => HTMLElement;
    CodeCell: (cell: import("ipynb2html-core").CodeCell, notebook: import("ipynb2html-core").Notebook) => HTMLElement;
    Source: (cell: import("ipynb2html-core").CodeCell, notebook: import("ipynb2html-core").Notebook) => HTMLElement;
    Output: (output: import("ipynb2html-core").Output, cell: import("ipynb2html-core").CodeCell) => HTMLElement;
    DisplayData: (output: import("ipynb2html-core").DisplayData) => HTMLElement;
    ExecuteResult: (output: import("ipynb2html-core").ExecuteResult) => HTMLElement;
    Error: (error: import("ipynb2html-core").ErrorOutput) => HTMLElement;
    Stream: (stream: import("ipynb2html-core").StreamOutput) => HTMLElement;
} & ((notebook: import("ipynb2html-core").Notebook) => HTMLElement);
/**
 * Builds a full-fledged Notebook renderer for server-side rendering with a
 * fake DOM implementation "nodom".
 *
 * It supports rendering of Markdown cells with math (using marked and KaTeX),
 * code highlighting (using highlight.js), rendering of ANSI escape sequences
 * (using Anser) and SageMath-style math outputs. All of them may be overridden
 * via *opts*.
 *
 * It returns a "callable object" that exposes one renderer function for each
 * of the Notebook's AST nodes. You can easily replace any of the functions to
 * modify behaviour of the renderer.
 */
export default _default;
//# sourceMappingURL=index.d.ts.map